BEGIN TRANSACTION;

PRAGMA foreign_keys = OFF;

/* change tele data table */

CREATE TABLE tele_data(
    'id' INTEGER PRIMARY KEY,
    'parent_id' INTEGER REFERENCES track('id') ON DELETE CASCADE,
    'type' TEXT,
    'time' REAL,
    'value' REAL
);

INSERT INTO tele_data(
    'parent_id',
    'type',
    'time',
    'value'
) SELECT
    parent_id,
    'TelemetryDataTypeGPSSpeed',
    time,
    value
FROM gps_speed_telemetry_data;

DROP TABLE IF EXISTS gps_speed_telemetry_data;

/* change stage table */

CREATE TABLE stage_temp(
    'id' INTEGER,
    'server_id' INTEGER,
    'light_track_id' INTEGER
);

INSERT INTO stage_temp(
    'id',
    'server_id',
    'light_track_id'
) SELECT
    id,
    server_id,
    light_track_id
FROM stage;

DROP TABLE IF EXISTS stage;

CREATE TABLE stage(
    'id' INTEGER PRIMARY KEY,
    'server_id' INTEGER
);

INSERT INTO stage(
    'id',
    'server_id'
) SELECT
    id,
    server_id
FROM stage_temp;

/* change track table */

CREATE TABLE track_temp(
    'id' INTEGER,
    'parent_id' INTEGER REFERENCES stage('id') ON DELETE CASCADE,
    'type' INTEGER(2) DEFAULT 0,
    'server_id' INTEGER
);

INSERT INTO track_temp(
    'id',
    'parent_id',
    'type',
    'server_id'
) SELECT
    id,
    parent_id,
    0,
    server_id
FROM track;

INSERT INTO track_temp
    SELECT t.id, s.id, 1, t.server_id FROM track_temp AS t
        INNER JOIN stage_temp AS s
            ON t.id = s.light_track_id;

DELETE FROM track_temp WHERE parent_id = 0;

DROP TABLE stage_temp;

DROP TABLE track;

CREATE TABLE track(
    'id' INTEGER PRIMARY KEY,
    'parent_id' INTEGER REFERENCES stage('id') ON DELETE CASCADE,
    'type' INTEGER(2) DEFAULT 0,
    'server_id' INTEGER
);

INSERT INTO track(
    'id',
    'parent_id',
    'type',
    'server_id'
) SELECT
    id,
    parent_id,
    type,
    server_id
FROM track_temp;

DROP TABLE track_temp;

/* change tele data table */

CREATE TABLE coordinate_temp(
    'id' INTEGER,
    'parent_id' INTEGER REFERENCES track('id') ON DELETE CASCADE,
    'lon' REAL,
    'lat' REAL,
    'altitude' REAL,
    'time' TEXT,
    'is_nick' BLOB(1),
    'distance' REAL,
    'course' REAL,
    'accuracy_horizontal' REAL,
    'accuracy_vertical' REAL
);

INSERT INTO coordinate_temp(
    'id',
    'parent_id',
    'lon',
    'lat',
    'altitude',
    'time',
    'is_nick',
    'distance',
    'course',
    'accuracy_horizontal',
    'accuracy_vertical'
) SELECT
    id,
    parent_id,
    lon,
    lat,
    altitude,
    time,
    is_nick,
    distance,
    course,
    accuracy_horizontal,
    accuracy_vertical
FROM coordinate;

DROP TABLE coordinate;

CREATE TABLE coordinate(
    'id' INTEGER PRIMARY KEY,
    'parent_id' INTEGER REFERENCES track('id') ON DELETE CASCADE,
    'lon' REAL,
    'lat' REAL,
    'altitude' REAL,
    'time' TEXT,
    'is_nick' BLOB(1),
    'distance' REAL,
    'course' REAL,
    'accuracy_horizontal' REAL,
    'accuracy_vertical' REAL
);

INSERT INTO coordinate(
    'id',
    'parent_id',
    'lon',
    'lat',
    'altitude',
    'time',
    'is_nick',
    'distance',
    'course',
    'accuracy_horizontal',
    'accuracy_vertical'
) SELECT
    id,
    parent_id,
    lon,
    lat,
    altitude,
    time,
    is_nick,
    distance,
    course,
    accuracy_horizontal,
    accuracy_vertical
FROM coordinate_temp;

DROP TABLE coordinate_temp;

/* change stage property table */

CREATE TABLE stage_property_temp(
    'id' INTEGER,
    'parent_id' INTEGER REFERENCES stage('id') ON DELETE CASCADE,
    'type' INTEGER(3),
    'value' TEXT
);

INSERT INTO stage_property_temp(
    'id',
    'parent_id',
    'type',
    'value'
) SELECT
    id,
    parent_id,
    type,
    value
FROM stage_property;

DROP TABLE stage_property;

CREATE TABLE stage_property(
    'id' INTEGER PRIMARY KEY,
    'parent_id' INTEGER REFERENCES stage('id') ON DELETE CASCADE,
    'type' INTEGER(3),
    'value' TEXT
);

INSERT INTO stage_property(
    'id',
    'parent_id',
    'type',
    'value'
) SELECT
    id,
    parent_id,
    type,
    value
FROM stage_property_temp;

DROP TABLE stage_property_temp;

/* change track property table */

CREATE TABLE track_property_temp(
    'id' INTEGER PRIMARY KEY,
    'parent_id' INTEGER REFERENCES track('id') ON DELETE CASCADE,
    'type' INTEGER(3),
    'value' TEXT
);

INSERT INTO track_property_temp(
    'id',
    'parent_id',
    'type',
    'value'
) SELECT
    id,
    parent_id,
    type,
    value
FROM track_property;

DROP TABLE track_property;

CREATE TABLE track_property(
    'id' INTEGER PRIMARY KEY,
    'parent_id' INTEGER REFERENCES track('id') ON DELETE CASCADE,
    'type' INTEGER(3),
    'value' TEXT
);

INSERT INTO track_property(
    'id',
    'parent_id',
    'type',
    'value'
) SELECT
    id,
    parent_id,
    type,
    value
FROM track_property_temp;

DROP TABLE track_property_temp;

/* change address table */

ALTER TABLE address ADD COLUMN 'state' TEXT;
ALTER TABLE address ADD COLUMN 'sub_region' TEXT;

/* delete old tables */

DROP TABLE IF EXISTS obd_speed_telemetry_data;
DROP TABLE IF EXISTS obd_engine_rpm_telemetry_data;
DROP TABLE IF EXISTS obd_throtle_position_telemetry_data;

DROP TABLE IF EXISTS gps_speed_telemetry_datas;
DROP TABLE IF EXISTS obd_speed_telemetry_datas;
DROP TABLE IF EXISTS obd_engine_rpm_telemetry_datas;
DROP TABLE IF EXISTS obd_throtle_position_telemetry_datas;

/* update settings */

UPDATE setting SET value='2' WHERE name='db_version';

PRAGMA foreign_keys = ON;

END TRANSACTION;